<?php
namespace boru\dot;

class DotArray {
    private $array = [];
    public function __construct($array=[]) {
        $this->array = $array;
    }
    public function get($dotKey,$default=null) {
        return Dot::get($this->array,$dotKey,$default);
    }
    public function set($dotKey,$value) {
        Dot::set($this->array,$dotKey,$value);
    }
    public function toArray() {
        return $this->array;
    }
    public function fromArray($array) {
        $this->array = $array;
    }
    public function parse($separator='.') {
        Dot::parse($this->array,$separator);
    }
    public function __toString() {
        return json_encode($this->array);
    }
}